@@ -367,6 +367,8 @@ sub _add_transform
                  fk          => FK_TYPE( default => undef ),
                  select      => SELECT_TYPE( default => undef ),
                  bind_params => CODEREF_TYPE( default => sub {} ),
+                 handles     => { default => undef },
+                 undef       => BOOLEAN_TYPE( default => undef ),
                };
 
     sub _add_has_one_relationship
@@ -411,8 +413,12 @@ sub _make_has_one
         # If given a select SQL for the has_one relationship we assume
         # it can always be undef, since we don't know the content of
         # the SQL.
-        my $can_be_undef =
-            $p{select} || grep { $_->is_nullable() } @{ $p{fk}->source_columns() };
+        my $can_be_undef = $p{undef};
+
+        unless ( defined $can_be_undef )
+        {
+            $can_be_undef = $p{select} || grep { $_->is_nullable() } @{ $p{fk}->source_columns() };
+        }
 
         # It'd be nice to set isa to the actual foreign class, but we may
         # not be able to map a table to a class yet, since that depends on
@@ -422,13 +428,17 @@ sub _make_has_one
         my $type = 'Fey::Object::Table';
         $type = "Maybe[$type]" if $can_be_undef;
 
-        $self->add_attribute
-            ( $name,
-              is      => 'ro',
-              isa     => $type,
-              lazy    => 1,
-              default => $default_sub,
-            );
+        my %attr_p = ( is      => 'rw',
+                       isa     => $type,
+                       lazy    => 1,
+                       default => $default_sub,
+                       writer  => q{_set_} . $name,
+                     );
+
+        $attr_p{handles} = $p{handles}
+            if $p{handles};
+
+        $self->add_attribute( $name, %attr_p );
     }
     else
     {
@@ -637,10 +647,11 @@ sub _make_has_many
 
         $self->add_attribute
             ( $attr_name,
-              is      => 'ro',
+              is      => 'rw',
               isa     => $iterator_class,
               lazy    => 1,
               default => $default_sub,
+              writer  => q{_set_} . $name,
             );
 
         my $method = sub { my $iterator = $_[0]->$attr_name();
